@@ -1,10 +1,13 @@
 import pandas as pd
 
 import gspread
+import requests
 
 from oauth2client.service_account import ServiceAccountCredentials
 
 from googleapiclient.discovery import build
+from requests.adapters import HTTPAdapter
+from urllib3 import Retry
 
 """ 
 Read google sheet as dataframe
@@ -14,28 +17,26 @@ If you read with API, you need to use spreadsheetId and credentials (it is the j
 you also need to add the account email associated to the credentials as user shared in the google sheet.
 
 """
-def read_gsheet(spreadsheetId = None, url = None, credentials = None, sheet = None):
+def read_gsheet(spreadsheetId, credentials = None, sheet = None):
     
 
-    if url and credentials != True:
-
-        gc = gspread.service_account(credentials)
-
-        if sheet != None:
-
-            wks = gc.open_by_url(url).worksheet(sheet)
-
-        else:
-
-            wks = gc.open_by_url(url).get_worksheet(0)
-
-
-        data = wks.get_values(value_render_option='UNFORMATTED_VALUE', date_time_render_option = "FORMATTED_STRING")
-
-        headers = data.pop(0)
-
-        df = pd.DataFrame(data, columns = headers)
+    if credentials is None:
 
+        post_url = "https://api.askdata.com/smartnotebook/readGsheet"
+        body = {
+            "spreadsheetId": spreadsheetId,
+            "sheet": sheet
+        }
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+        headers = {
+            "Content-Type": "application/json"
+        }
+        r = s.put(url=post_url, json=body, headers=headers)
+        r.raise_for_status()
+        df = pd.read_json(r.json())
 
     else: 
 
@@ -47,7 +48,7 @@ def read_gsheet(spreadsheetId = None, url = None, credentials = None, sheet = No
     
         sheet = service.spreadsheets()
         
-        result_input = sheet.values().get(spreadsheetId=SAMPLE_SPREADSHEET_ID_input,
+        result_input = sheet.values().get(spreadsheetId = spreadsheetId,
                                           range='A1:WWW500000').execute()
         
         values_input = result_input.get('values', [])
@@ -159,8 +160,7 @@ def __read_excel(settings: dict):
     return df
 
 def __read_gsheet(settings: dict):
-    df = read_gsheet(settings["url"])
-
+    df = read_gsheet(spreadsheetId=settings["spreadsheetId"], credentials=settings["credentials"], sheet=settings["sheet"])
     return df
 
 def __read_hubspot(settings: dict):
